import { useState, useRef, useCallback, useEffect, useMemo } from 'react';
import { NativeModules, NativeEventEmitter, Platform } from 'react-native';
export default (() => {
  const {
    AndroidSmsVerification
  } = NativeModules;
  const [message, setMessage] = useState('');
  const listenerRef = useRef();
  const eventEmitter = useMemo(() => new NativeEventEmitter(AndroidSmsVerification), [AndroidSmsVerification]);
  useEffect(() => {
    if (Platform.OS === 'android') {
      const onStartListener = eventEmitter.addListener('onListenerStarted', event => console.info(event));
      const onRegisterListener = eventEmitter.addListener('onReceiverRegistered', event => console.info(event));
      const onUnregisterListener = eventEmitter.addListener('onReceiverUnregistered', event => console.info(event));
      return () => {
        onStartListener === null || onStartListener === void 0 ? void 0 : onStartListener.remove();
        onRegisterListener === null || onRegisterListener === void 0 ? void 0 : onRegisterListener.remove();
        onUnregisterListener === null || onUnregisterListener === void 0 ? void 0 : onUnregisterListener.remove();
      };
    }

    return () => null;
  }, [eventEmitter]);
  const startListener = useCallback(() => {
    if (Platform.OS === 'android') {
      try {
        AndroidSmsVerification.registerBroadcastReceiver();
        AndroidSmsVerification.startBroadcastReceiver();
        listenerRef.current = eventEmitter.addListener('onMessageReceived', setMessage);
      } catch (error) {
        console.error(error);
      }
    }
  }, [AndroidSmsVerification, eventEmitter]);
  const stopListener = useCallback(() => {
    if (Platform.OS === 'android') {
      try {
        var _listenerRef$current;

        AndroidSmsVerification.unRegisterBroadcastReceiver();
        (_listenerRef$current = listenerRef.current) === null || _listenerRef$current === void 0 ? void 0 : _listenerRef$current.remove();
      } catch (error) {
        console.error(error);
      }
    }
  }, [AndroidSmsVerification]);
  return {
    message,
    startListener,
    stopListener
  };
});
//# sourceMappingURL=sms-retriver.js.map